@@ -2,6 +2,7 @@ import os
 import sys
 import uuid
 import traceback
+import json
 
 try:
     from StringIO import StringIO
@@ -10,9 +11,18 @@ except:
 
 import param
 
-__version__ = str(param.version.Version(fpath=__file__, archive_commit="$Format:%h$",
-                                        reponame="pyviz_comms"))
+from ._version import __version__
 
+HERE = os.path.abspath(os.path.dirname(__file__))
+
+with open(os.path.join(HERE, 'labextension', 'package.json')) as fid:
+    data = json.load(fid)
+
+def _jupyter_labextension_paths():
+    return [{
+        'src': 'labextension',
+        'dest': data['name']
+    }]
 
 # nb_mime_js is used to enable the necessary mime type support in classic notebook
 comm_path = os.path.dirname(os.path.abspath(__file__))
@@ -20,7 +30,6 @@ with open(os.path.join(comm_path, 'notebook.js')) as f:
     nb_mime_js = '\n\n' + f.read()
 
 
-
 class extension(param.ParameterizedFunction):
     """
     Base class for pyviz extensions, which allow defining shared cleanup
@@ -326,7 +335,7 @@ class Comm(param.Parameterized):
                 pass
             error = '\n'
             frames = traceback.extract_tb(sys.exc_info()[2])
-            for frame in frames[-10:]:
+            for frame in frames[-20:]:
                 fname,lineno,fn,text = frame
                 error_kwargs = dict(fn=fn, fname=fname, line=lineno)
                 error += '{fname} {fn} L{line}\n'.format(**error_kwargs)
@@ -540,10 +549,10 @@ class JupyterCommManager(CommManager):
             console.log(message)
             var content = {data: message.data, comm_id};
             var buffers = []
-            for (var buffer of message.buffers ?? []) {
+            for (var buffer of message.buffers || []) {
               buffers.push(new DataView(buffer))
             }
-            var metadata = message.metadata ?? {};
+            var metadata = message.metadata || {};
             var msg = {content, buffers, metadata}
             msg_handler(msg);
             return messages.next().then(processIteratorResult);
@@ -577,7 +586,7 @@ class JupyterCommManager(CommManager):
             function processIteratorResult(result) {
               var message = result.value;
               var content = {data: message.data};
-              var metadata = message.metadata ?? {comm_id};
+              var metadata = message.metadata || {comm_id};
               var msg = {content, metadata}
               msg_handler(msg);
               return messages.next().then(processIteratorResult);
